@@ -80,17 +80,17 @@ namespace {
 
 		struct stat boot;
 		if(stat("/boot", &boot) < 0)
-			return fmt::format("find_esp(): stat(\"/boot\"): {}", strerror(errno));
+			return fmt::format("find_esp(): stat(\"/boot\"): {}", std::strerror(errno));
 
 		struct stat boot_efi;
 		if(stat("/boot/efi", &boot_efi) < 0) {
 			if(errno != ENOENT)
-				return fmt::format("find_esp(): stat(\"/boot/efi\"): {}", strerror(errno));
+				return fmt::format("find_esp(): stat(\"/boot/efi\"): {}", std::strerror(errno));
 			else {
 				esp      = "/boot";
 				boot_efi = boot;
 				if(stat("/", &boot) < 0)
-					return fmt::format("find_esp(): stat(\"/\"): {}", strerror(errno));
+					return fmt::format("find_esp(): stat(\"/\"): {}", std::strerror(errno));
 			}
 		}
 
