@@ -72,21 +72,21 @@ namespace {
 	std::variant<bool, std::string> copy_file(int srcdir, int destdir, const char * basename, sha_t cursha, bool verbose) {
 		auto srcfd = openat(srcdir, basename, O_RDONLY);
 		if(srcfd < 0)
-			return fmt::format("Couldn't open {} for reading: {}\n", basename, strerror(errno));
+			return fmt::format("Couldn't open {} for reading: {}\n", basename, std::strerror(errno));
 		klapki::quickscope_wrapper srcfd_deleter{[&] { close(srcfd); }};
 
 		struct stat src_sb;
 		if(fstat(srcfd, &src_sb) < 0)
-			return fmt::format("Couldn't stat() source {}: {}\n", basename, strerror(errno));
+			return fmt::format("Couldn't stat() source {}: {}\n", basename, std::strerror(errno));
 
 		sha_t insha{};
 		{
 			auto map = mmap(nullptr, src_sb.st_size, PROT_READ, MAP_PRIVATE, srcfd, 0);
 			if(!map)
-				return fmt::format("Couldn't mmap() source {}: {}\n", basename, strerror(errno));
+				return fmt::format("Couldn't mmap() source {}: {}\n", basename, std::strerror(errno));
 			klapki::quickscope_wrapper map_deleter{[&] {
 				if(munmap(map, src_sb.st_size))
-					fmt::print(stderr, "munmap {}: {}\n", basename, strerror(errno));
+					fmt::print(stderr, "munmap {}: {}\n", basename, std::strerror(errno));
 			}};
 
 			SHA1(reinterpret_cast<const unsigned char *>(map), src_sb.st_size, insha);
@@ -98,7 +98,7 @@ namespace {
 			struct stat dest_sb;  // Still copy if missning
 			if(fstatat(destdir, basename, &dest_sb, 0) < 0) {
 				if(errno != ENOENT)
-					return fmt::format("Couldn't stat() source {}: {}\n", basename, strerror(errno));
+					return fmt::format("Couldn't stat() source {}: {}\n", basename, std::strerror(errno));
 			} else
 				return false;
 		}
@@ -109,16 +109,16 @@ namespace {
 
 		auto destfd = openat(destdir, basename, O_WRONLY | O_CREAT | O_TRUNC, 0644);
 		if(destfd < 0)
-			return fmt::format("Couldn't open {} for writing: {}\n", basename, strerror(errno));
+			return fmt::format("Couldn't open {} for writing: {}\n", basename, std::strerror(errno));
 		klapki::quickscope_wrapper destfd_deleter{[&] {
 			if(close(destfd))
-				fmt::print(stderr, "Warning: destination {} errored on close: {}", basename, strerror(errno));
+				fmt::print(stderr, "Warning: destination {} errored on close: {}", basename, std::strerror(errno));
 		}};
 
 		off_t offset = 0;
 		for(ssize_t res = 0; res < src_sb.st_size; res = sendfile(destfd, srcfd, &offset, src_sb.st_size)) {
 			if(res < 0)
-				return fmt::format("Couldn't copy to {} (offset {}): {}\n", basename, offset, strerror(errno));
+				return fmt::format("Couldn't copy to {} (offset {}): {}\n", basename, offset, std::strerror(errno));
 
 			src_sb.st_size -= res;
 		}
@@ -131,7 +131,7 @@ namespace {
 std::optional<std::string> klapki::context::context::commit(const config & cfg, state::state & state) const {
 	auto esp_fd = open(cfg.esp.data(), O_RDONLY | O_DIRECTORY | O_PATH);
 	if(esp_fd < 0)
-		return fmt::format("Couldn't open ESP ({}): {}\n", cfg.esp, strerror(errno));
+		return fmt::format("Couldn't open ESP ({}): {}\n", cfg.esp, std::strerror(errno));
 	quickscope_wrapper esp_fd_deleter{[&] { close(esp_fd); }};
 
 	std::map<std::string_view, int, caseless> esp_dirs;
@@ -161,15 +161,15 @@ std::optional<std::string> klapki::context::context::commit(const config & cfg,
 			for(auto slash_idx = dir.find('/'); slash_idx != std::string::npos; slash_idx = dir.find('/', slash_idx + 1)) {
 				dir[slash_idx] = '\0';
 				if(mkdirat(esp_fd, dir.c_str(), 0755) < 0 && errno != EEXIST)
-					return fmt::format("Couldn't create {} under ESP ({}): {}\n", dir.c_str(), cfg.esp, strerror(errno));
+					return fmt::format("Couldn't create {} under ESP ({}): {}\n", dir.c_str(), cfg.esp, std::strerror(errno));
 				dir[slash_idx] = '/';
 			}
 			if(mkdirat(esp_fd, dir.c_str(), 0755) < 0 && errno != EEXIST)
-				return fmt::format("Couldn't create {} under ESP ({}): {}\n", dir, cfg.esp, strerror(errno));
+				return fmt::format("Couldn't create {} under ESP ({}): {}\n", dir, cfg.esp, std::strerror(errno));
 
 			auto fd = openat(esp_fd, dir.c_str(), O_RDONLY | O_DIRECTORY | O_PATH);
 			if(fd < 0)
-				return fmt::format("Couldn't open {} under ESP ({}): {}\n", dir, cfg.esp, strerror(errno));
+				return fmt::format("Couldn't open {} under ESP ({}): {}\n", dir, cfg.esp, std::strerror(errno));
 			esp_dirs.emplace(ddir, fd);
 			cbk(std::move(dir));
 		}
@@ -199,7 +199,7 @@ std::optional<std::string> klapki::context::context::commit(const config & cfg,
 	for(auto && [path, dir_ents] : source_dirs) {
 		dir_ents.first = opendir(path.get().data());
 		if(!dir_ents.first)
-			return fmt::format("Couldn't open {}: {}\n", path.get(), strerror(errno));
+			return fmt::format("Couldn't open {}: {}\n", path.get(), std::strerror(errno));
 
 		while(const auto ent = readdir(dir_ents.first))
 			dir_ents.second.emplace(ent->d_name);
@@ -273,7 +273,7 @@ std::optional<std::string> klapki::context::context::commit(const config & cfg,
 
 		fmt::print("Removing {} from {}\n", dfile, ddir);
 		if(unlinkat(destfd->second, dfile.c_str(), 0) < 0 && unlinkat(destfd->second, dfile.c_str(), AT_REMOVEDIR) < 0)
-			return fmt::format("Removing {} from {}: {}", dfile, ddir, strerror(errno));
+			return fmt::format("Removing {} from {}: {}", dfile, ddir, std::strerror(errno));
 	}
 
 	for(auto && ddir : deleted_dir_names) {
@@ -281,7 +281,7 @@ std::optional<std::string> klapki::context::context::commit(const config & cfg,
 			fmt::print("Cleaning up {} from {}\n", ddir, cfg.esp);
 		if(unlinkat(esp_fd, ddir.c_str(), AT_REMOVEDIR) < 0)
 			if(cfg.verbose)
-				fmt::print("Removing {} from {}: {}\n", ddir, cfg.esp, strerror(errno));
+				fmt::print("Removing {} from {}: {}\n", ddir, cfg.esp, std::strerror(errno));
 	}
 
 
