@@ -24,7 +24,7 @@
 #include "context.hpp"
 #include "context_detail.hpp"
 #include "quickscope_wrapper.hpp"
-#include <sys/mman.h>
+#include <fcntl.h>
 #include <sys/types.h>
 #include <sys/wait.h>
 #include <unistd.h>
@@ -40,66 +40,69 @@
 
 
 namespace {
-	struct mapped_chunk {
-		std::string_view data;
-		std::shared_ptr<void> data_cont;
-
-		static std::variant<mapped_chunk, std::string> from_fd(const char * for_whom, int fd) {
-			struct stat sb;
-			if(fstat(fd, &sb) < 0)
-				return fmt::format("{} file stat(): {}", for_whom, strerror(errno));
-
-			auto map = mmap(nullptr, sb.st_size, PROT_READ | PROT_WRITE, MAP_PRIVATE, fd, 0);
-			if(map == MAP_FAILED)
-				return fmt::format("{} file mmap(): {}", for_whom, strerror(errno));
-
-			return mapped_chunk{{static_cast<char *>(map), static_cast<std::size_t>(sb.st_size)}, {map, [size = sb.st_size](auto map) { munmap(map, size); }}};
-		}
+	struct wisdom {
+		std::string data;
 	};
 
-	std::variant<mapped_chunk, std::string> gain_wisdom(const klapki::config & cfg, const char * from, const char * version, const char * variant) {
-		auto fd = memfd_create(from, MFD_CLOEXEC);
-		if(fd < 0)
-			return fmt::format("opening {} {} {} file: {}", from, version, variant, strerror(errno));
-		klapki::quickscope_wrapper cmdline_fd_del{[&] { close(fd); }};
+	std::variant<wisdom, std::string> gain_wisdom(const klapki::config & cfg, const char * from, const char * version, const char * variant) {
+		int comm[2];
+		if(pipe2(comm, O_CLOEXEC) < 0)
+			return fmt::format("opening {} {} {} file: {}", from, version, variant, std::strerror(errno));
 
 		switch(auto pid = fork()) {
 			case -1:
-				return fmt::format("forking for {} {} {}: {}", from, version, variant, strerror(errno));
+				close(comm[0]);
+				close(comm[1]);
+				return fmt::format("forking for {} {} {}: {}", from, version, variant, std::strerror(errno));
 
 			case 0: {  // child
-				if(dup2(fd, 1) < 0)
-					exit(0x6B);
+				if(dup2(comm[1], 1) < 0)
+					_exit(0x6B);
 
 				const auto hook = fmt::format("{}{}", cfg.wisdom_root(), from);
-				execl(hook.c_str(), from, version, variant, (char *)NULL);
-				fmt::print(stderr, "exec {} {} {}: {}\n", hook, version, variant, strerror(errno));
-				exit(0x6B);
+				execl(hook.c_str(), from, version, variant, (char *)nullptr);
+				fmt::print(stderr, "exec {} {} {}: {}\n", hook, version, variant, std::strerror(errno));
+				_exit(0x6B);
 			}
 
-			default:  // parent
+			default: {  // parent
+				close(comm[1]);
+				klapki::quickscope_wrapper cmdline_fd_del{[&] { close(comm[0]); }};
+
+				wisdom ret;
+				char buf[64 * 1024];
+				for(ssize_t rd = -1; rd;) {
+					while((rd = read(comm[0], buf, sizeof(buf))) == -1 && errno == EINTR)
+						;
+					if(rd < 0)
+						return fmt::format("{} read failed with {}", from, std::strerror(errno));
+					ret.data.append(buf, rd);
+				}
+
 				int result;
 				waitpid(pid, &result, 0);
 				if(WIFEXITED(result) && WEXITSTATUS(result) != 0)
 					return fmt::format("{} child returned {}", from, WEXITSTATUS(result));
 				else if(WIFSIGNALED(result))
-					return fmt::format("{} child killed by signal {}", from, WTERMSIG(result));
+					return fmt::format("{} child killed by signal {} ({})", from, WTERMSIG(result), strsignal(WTERMSIG(result)));
 
-				return mapped_chunk::from_fd("cmdline", fd);
+				if(auto idx = ret.data.find('\0'); idx != std::string::npos)  // end at first NUL, if any; prevent unexpected behaviour by behaving like a C string
+					ret.data.erase(idx);
+
+				// Character set stolen from isspace()
+				ret.data.erase(ret.data.find_last_not_of(" \f\n\r\t\v") + 1);
+				ret.data.erase(0, ret.data.find_first_not_of(" \f\n\r\t\v"));
+
+				std::replace(std::begin(ret.data), std::end(ret.data), '\n', ' ');
+
+				return ret;
+			}
 		}
 	}
 
-	void trim(std::string_view & str) {
-		// Character set stolen from isspace()
-		str.remove_prefix(std::min(str.find_first_not_of(" \f\n\r\t\v"), str.size()));
-		str.remove_suffix(std::min(str.size() - str.find_last_not_of(" \f\n\r\t\v") - 1, str.size()));
-	}
-
-	void denewline(std::string_view & str) { std::replace(const_cast<char *>(std::begin(str)), const_cast<char *>(std::end(str)), '\n', ' '); }
-
-	void validate_cmdline(const std::string_view & cmdline) {
+	void validate_cmdline(const std::string & cmdline) {
 		klapki::context::detail::tokenise_cmdline(cmdline, [&](auto && arg) {
-			if(arg.substr(0, std::strlen("initrd=")) == "initrd=") {  // string_view::starts_with() is C++20
+			if(arg.substr(0, std::strlen("initrd=")) == "initrd=") {  // string::starts_with() is C++20
 				fmt::print(stderr, "Stray {} in cmdline, things might not work as planned\n", arg);
 				return false;
 			} else
@@ -115,16 +118,9 @@ std::optional<std::string> klapki::context::context::wisen(const config & cfg, s
 		if(skern == std::end(state.statecfg.wanted_entries))
 			throw __func__;
 
-		auto description = TRY(gain_wisdom(cfg, "description", skern->version.c_str(), skern->variant.c_str()));
-		auto cmdline     = TRY(gain_wisdom(cfg, "cmdline", skern->version.c_str(), skern->variant.c_str()));
-		trim(description.data);
-		trim(cmdline.data);
-		denewline(description.data);
-		denewline(cmdline.data);
-		validate_cmdline(cmdline.data);
-
-		kern.description = description.data;
-		kern.cmdline     = cmdline.data;
+		kern.description = std::move(TRY(gain_wisdom(cfg, "description", skern->version.c_str(), skern->variant.c_str())).data);
+		kern.cmdline     = std::move(TRY(gain_wisdom(cfg, "cmdline", skern->version.c_str(), skern->variant.c_str())).data);
+		validate_cmdline(kern.cmdline);
 	}
 
 	return {};
